@@ -1,6 +1,6 @@
 package Config::Scoped;
 
-# $Id: Scoped.pm,v 1.27 2004/08/02 11:05:20 gaissmai Exp gaissmai $
+# $Id: Scoped.pm,v 1.28 2004/08/02 12:42:59 gaissmai Exp $
 
 =head1 NAME
 
@@ -37,7 +37,7 @@ use Config::Scoped::Error;
 # inherit from a precompiled grammar package
 use base 'Config::Scoped::Precomp';
 
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 my @state_hashes = qw(config params macros warnings includes);
 
@@ -373,6 +373,7 @@ May take a set of named parameters as key => value pairs. Returns a Config::Scop
 
     my $parser = Config::Scoped->new(
         file      => '/etc/appl/foo.cfg',
+        lc        => 1,
         safe      => $your_compartment,
         your_item => $your_value,
 
@@ -393,6 +394,10 @@ May take a set of named parameters as key => value pairs. Returns a Config::Scop
 
 Optional, without a configuration file the parse() method needs a string to parse.
 
+=item B<lc =E<gt> true|false>
+
+Optional, if true converts all declaration and parameter names to I<lowercase>. Default is false.
+
 =item B<safe =E<gt> $compartment>
 
 Safe compartment, optional. Defaults to a Safe compartment with no extra shares and the :default operator tag.
@@ -442,6 +447,13 @@ sub new {
     #
     $thisparser->{local} = {%args};
 
+    # frequent typos, be polite
+    $thisparser->{local}{warnings} ||= $thisparser->{local}{warning};
+    $thisparser->{local}{lc}       ||= $thisparser->{local}{lowercase};
+    $thisparser->{local}{safe}     ||= $thisparser->{local}{Safe};
+    $thisparser->{local}{file}     ||= $thisparser->{local}{File};
+
+
     ##############################################
     # validate and munge the 'file' param
     #
@@ -1108,6 +1120,8 @@ sub _store_parameter {
         -text => Carp::shortmess("missing parameters") )
       unless ( defined $args{value} && defined $args{name} );
 
+    $args{name} = lc( $args{name} ) if $thisparser->{local}{lc};
+
     # parameter validation, may be overwritten by the application
     my $valid_value = $thisparser->parameter_validate(%args);
 
@@ -1170,6 +1184,12 @@ sub _store_declaration {
         -text => Carp::shortmess("missing parameters") )
       unless ( defined $args{name} && defined $args{value} );
 
+    {
+        local $_;
+        map { $_ = lc($_) } @{ $args{name} }
+          if $thisparser->{local}{lc};
+    }
+
     # convert declaration: foo bar ... baz { parameters }
     # to the data structure
     # $config->{foo}{bar}...{baz} = { parameters };
